@@ -5,6 +5,7 @@ import subprocess
 from typing import List, NoReturn, Union, Any
 
 from . import node
+from .utils import env_to_bool
 
 
 __all__ = (
@@ -29,10 +30,16 @@ def run(
     npx = node.version('npx')
     if npx[0] >= 7:
         pre_args = ['--yes']
+
+        if not env_to_bool('PYRIGHT_PYTHON_VERBOSE', default=False):
+            pre_args.insert(0, '--silent')
     else:
         pre_args = []
 
-    return node.run('npx', *pre_args, f'pyright@{version}', '--', *args, **kwargs)
+    if args and pre_args:
+        pre_args = (*pre_args, '--')
+
+    return node.run('npx', *pre_args, f'pyright@{version}', *args, **kwargs)
 
 
 def entrypoint() -> NoReturn:
